@@ -616,11 +616,13 @@ is.dfm <- function(x) {
 as.dfm <- function(x) {
     if (!any((c("matrix", "data.frame") %in% class(x))))
         stop("as.dfm only applicable to matrix(-like) objects.")
-    m <- as.matrix(x)
-    attr(m, "settings") <- attr(x, "settings")
-    attr(m, "weighting") <- attr(x, "weighting")
-    class(m) <- class(x)
-    m
+    new("dfmSparse", Matrix(as.matrix(x), sparse=TRUE))
+    #     
+    #     m <- as.matrix(x)
+    #     attr(m, "settings") <- attr(x, "settings")
+    #     attr(m, "weighting") <- attr(x, "weighting")
+    #     class(m) <- class(x)
+    #     m
 }
 
 
